@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -30,7 +30,7 @@
 #include "kchmviewwindow_qtextbrowser.h"
 
 #if defined (USE_KDE)
-	#include "kchmviewwindow_khtmlpart.h"
+	#include "kde/kchmviewwindow_khtmlpart.h"
 #endif
 
 
